<?php

namespace Drupal\cache_debugger\Form;

use Drupal;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Cache Debugger.
 *
 * @package Drupal\cache_debugger\Form
 */
class CacheDebugger extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['cache_debugger.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cache_debugger_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('cache_debugger.settings');

    $form['cache_debugger_block'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Configure Cache debugging'),
    ];

    $form['cache_debugger_block']['cache_debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable cache debugging'),
      '#description' => $this->t('This setting will add cache debugging output for each rendered element.'),
      '#default_value' => $config->get('cache_debug'),
    ];

    return parent::buildForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    
    $this->config('cache_debugger.settings')
      ->set('cache_debug', $form_state->getValue('cache_debug'))
      ->save();

    if ($form_state->getValue('cache_debug')) {
      Drupal::messenger()->addMessage($this->t('Cache debugging has been enabled.'));

      $destination = DRUPAL_ROOT . '/sites/default/services.yml';
      if (file_exists($destination) === FALSE) {
        $source = DRUPAL_ROOT . '/sites/default/default.services.yml';
        chmod(DRUPAL_ROOT . '/sites/default', 0777);
        touch($destination);
        copy($source, $destination);
        chmod(DRUPAL_ROOT . '/sites/default', 0555);

        $pos = strrpos(file_get_contents($destination), 'debug: false');
        if ($pos !== false) {
            $newstring = substr_replace(file_get_contents($destination), 'debug: true', $pos);
        }
        file_put_contents($destination, $newstring);
        drupal_flush_all_caches();
      }
    } else {
      Drupal::messenger()->addMessage($this->t('Cache debugging has been disabled.'));
      $source = DRUPAL_ROOT . '/sites/default/services.yml';
      if (file_exists($source) === TRUE) {
        chmod(DRUPAL_ROOT . '/sites/default', 0777);
        unlink($source);
        chmod(DRUPAL_ROOT . '/sites/default', 0555);
        drupal_flush_all_caches();
      }

    }


    // Save the configuration.
    parent::submitForm($form, $form_state);
    
  }

}
